@@ -65,6 +65,9 @@ FAILEDOPERATION_CERTIFICATEIDVERIFYFAIL = 'FailedOperation.CertificateIdVerifyFa
 # Apis 证书为空，请上传证书。
 FAILEDOPERATION_CERTIFICATEISNULL = 'FailedOperation.CertificateIsNull'
 
+# 调用CLS服务失败。
+FAILEDOPERATION_CLSERROR = 'FailedOperation.ClsError'
+
 # API文档操作失败。
 FAILEDOPERATION_CODINGERROR = 'FailedOperation.CodingError'
 
@@ -185,6 +188,9 @@ INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 # 插件定义参数取值重复，请修改后重新操作。
 INVALIDPARAMETERVALUE_DUPLICATEPLUGINCONFIG = 'InvalidParameterValue.DuplicatePluginConfig'
 
+# 非法的后端ip地址。
+INVALIDPARAMETERVALUE_ILLEGALPROXYIP = 'InvalidParameterValue.IllegalProxyIp'
+
 # 密钥错误。
 INVALIDPARAMETERVALUE_INVALIDACCESSKEYIDS = 'InvalidParameterValue.InvalidAccessKeyIds'
 
@@ -272,6 +278,9 @@ INVALIDPARAMETERVALUE_INVALIDTAGVALUES = 'InvalidParameterValue.InvalidTagValues
 # TSF类型API配置错误。
 INVALIDPARAMETERVALUE_INVALIDTSFCONFIG = 'InvalidParameterValue.InvalidTsfConfig'
 
+# 当前后端通道不存在或者是无效状态。
+INVALIDPARAMETERVALUE_INVALIDUPSTREAM = 'InvalidParameterValue.InvalidUpstream'
+
 # URL参数错误。
 INVALIDPARAMETERVALUE_INVALIDURL = 'InvalidParameterValue.InvalidUrl'
 
@@ -338,6 +347,12 @@ LIMITEXCEEDED_USAGEPLANLIMITEXCEEDED = 'LimitExceeded.UsagePlanLimitExceeded'
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
+# 缺少后端服务参数。
+MISSINGPARAMETER_BACKENDSPECIFICPARAM = 'MissingParameter.BackendSpecificParam'
+
+# 插件缺少参数，请按规则重新操作。
+MISSINGPARAMETER_PLUGINCONFIG = 'MissingParameter.PluginConfig'
+
 # 操作被拒绝。
 OPERATIONDENIED = 'OperationDenied'
 
@@ -446,6 +461,9 @@ UNSUPPORTEDOPERATION_RESOURCEASSOCIATED = 'UnsupportedOperation.ResourceAssociat
 # 密钥已绑定使用计划，请先解绑再试。
 UNSUPPORTEDOPERATION_RESOURCEISINUSE = 'UnsupportedOperation.ResourceIsInUse'
 
+# 资源未关联。
+UNSUPPORTEDOPERATION_RESOURCEUNASSOCIATED = 'UnsupportedOperation.ResourceUnassociated'
+
 # 当前Uin未在手工密钥白名单列表内。
 UNSUPPORTEDOPERATION_UINNOTINWHITELIST = 'UnsupportedOperation.UinNotInWhiteList'
 
